@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateFlowService", params)
+            headers = request.headers
+            body = self.call("CreateFlowService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateFlowServiceResponse()
@@ -64,7 +65,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeExecution", params)
+            headers = request.headers
+            body = self.call("DescribeExecution", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeExecutionResponse()
@@ -92,7 +94,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeExecutionHistory", params)
+            headers = request.headers
+            body = self.call("DescribeExecutionHistory", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeExecutionHistoryResponse()
@@ -120,7 +123,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeExecutions", params)
+            headers = request.headers
+            body = self.call("DescribeExecutions", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeExecutionsResponse()
@@ -148,7 +152,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFlowServiceDetail", params)
+            headers = request.headers
+            body = self.call("DescribeFlowServiceDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFlowServiceDetailResponse()
@@ -176,7 +181,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFlowServices", params)
+            headers = request.headers
+            body = self.call("DescribeFlowServices", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFlowServicesResponse()
@@ -204,7 +210,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyFlowService", params)
+            headers = request.headers
+            body = self.call("ModifyFlowService", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyFlowServiceResponse()
@@ -232,7 +239,8 @@ class AswClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartExecution", params)
+            headers = request.headers
+            body = self.call("StartExecution", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartExecutionResponse()
@@ -243,6 +251,35 @@ class AswClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopExecution(self, request):
+        """终止某个状态机
+
+        :param request: Request instance for StopExecution.
+        :type request: :class:`tencentcloud.asw.v20200722.models.StopExecutionRequest`
+        :rtype: :class:`tencentcloud.asw.v20200722.models.StopExecutionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopExecution", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopExecutionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
